Module plugin

Module plugin 

Non-invasive module installation protocol.

Structs

PluginError
Error returned when a plugin cannot install itself into a World.
PluginRegistry
Internal record of which plugin types have been installed into a world.

Traits

Plugin
A non-invasive installer for an engine module.

Type Aliases

PluginResult
Result type returned by engine module plugins.