Non-invasive module installation protocol.
Structs
- Plugin
Error - Error returned when a plugin cannot install itself into a
World. - Plugin
Registry - Internal record of which plugin types have been installed into a world.
Traits
- Plugin
- A non-invasive installer for an engine module.
Type Aliases
- Plugin
Result - Result type returned by engine module plugins.